@@ -170,7 +170,7 @@ def hist(array, xmin, xmax, log, cumul, bins, weights, xlabel, title, fig_name):
         array,
         alpha=0.9,
         color="darkorange",
-        edgecolor="black",
+        edgecolor=edgecolor,
         bins=bins,
         range=[xmin, xmax],
         weights=weights,
@@ -212,7 +212,7 @@ def hist_st(array, xmin, xmax, log, cumul, bins, weights, xlabel, title):
         array,
         alpha=0.9,
         color="darkorange",
-        edgecolor="black",
+        edgecolor=edgecolor,
         bins=bins,
         range=[xmin, xmax],
         weights=weights,
